@@ -247,7 +247,7 @@ void MainWindow::on_addStationButton_clicked()
     QString radioName;
     QString radioFreq;
     bool ok;
-    radioName = QInputDialog::getText(this, "Station name", "Insert Name:", QLineEdit::Normal, ui->rdsRadioLabel->text(), &ok , 0);
+    radioName = QInputDialog::getText(this, tr("Station name"), tr("Insert Name:"), QLineEdit::Normal, ui->rdsRadioLabel->text(), &ok , 0);
     if (!ok) return;
     if (radioName.isEmpty()) return;
 
@@ -325,6 +325,8 @@ void MainWindow::setWidgetsEnabled(bool enable)
 
  ui->actionManual->setEnabled(enable);
  ui->actionAuto_Scan->setEnabled(enable);
+ ui->actionHeadphones->setEnabled(enable);
+ ui->actionSpeakers->setEnabled(enable);
 
  for (int i=0; i<4; i++)
  {
@@ -372,7 +374,7 @@ void MainWindow::on_actionInsert_here_triggered()
     QString radioName;
     QString radioFreq;
     bool ok;
-    radioName = QInputDialog::getText(this, "Station name", "Insert Name:", QLineEdit::Normal, ui->rdsRadioLabel->text(), &ok , 0);
+    radioName = QInputDialog::getText(this, tr("Station name"), tr("Insert Name:"), QLineEdit::Normal, ui->rdsRadioLabel->text(), &ok , 0);
     if (!ok) return;
     if (radioName.isEmpty()) return;
 
@@ -539,7 +541,7 @@ void MainWindow::on_actionManual_triggered()
 void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About QRadio"),
-                    tr("<h2>QRadio 0.4.1</h2>"
+                    tr("<h2>QRadio 0.4.2</h2>"
                        "<p>"
                        "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"));
 }
@@ -562,7 +564,7 @@ void MainWindow::on_actionSpeakers_triggered()
 {
     QProcess::execute("sh /opt/qradio/output.sh speaker");
     ui->volumeSlider->setValue(50);
-	radio->setVolume(100);
+    radio->setVolume(100);
 }
 
 void MainWindow::on_actionHeadphones_triggered()
