@@ -50,7 +50,7 @@ SettingsDialog::~SettingsDialog()
 void SettingsDialog::on_set1RenameButton_clicked()
 {
     bool ok;
-    QString nameTemp = QInputDialog::getText(this, "Set1 Rename", "Insert Set1 Name:", QLineEdit::Normal, ui->set1RadioButton->text(), &ok , 0);
+    QString nameTemp = QInputDialog::getText(this, tr("Set1 Rename"), tr("Insert Set1 Name:"), QLineEdit::Normal, ui->set1RadioButton->text(), &ok , 0);
     if (!ok) return;
 
     ui->set1RadioButton->setText(nameTemp);
@@ -61,7 +61,7 @@ void SettingsDialog::on_set1RenameButton_clicked()
 void SettingsDialog::on_set2RenameButton_clicked()
 {
     bool ok;
-    QString nameTemp = QInputDialog::getText(this, "Set2 Rename", "Insert Set2 Name:", QLineEdit::Normal, ui->set2RadioButton->text(), &ok , 0);
+    QString nameTemp = QInputDialog::getText(this, tr("Set2 Rename"), tr("Insert Set2 Name:"), QLineEdit::Normal, ui->set2RadioButton->text(), &ok , 0);
     if (!ok) return;
 
     ui->set2RadioButton->setText(nameTemp);
@@ -71,7 +71,7 @@ void SettingsDialog::on_set2RenameButton_clicked()
 void SettingsDialog::on_set3RenameButton_clicked()
 {
     bool ok;
-    QString nameTemp = QInputDialog::getText(this, "Set3 Rename", "Insert Set3 Name:", QLineEdit::Normal, ui->set3RadioButton->text(), &ok , 0);
+    QString nameTemp = QInputDialog::getText(this, tr("Set3 Rename"), tr("Insert Set3 Name:"), QLineEdit::Normal, ui->set3RadioButton->text(), &ok , 0);
     if (!ok) return;
 
     ui->set3RadioButton->setText(nameTemp);
